@@ -330,7 +330,7 @@ def __createModule__(moduleName, category):
                                                                               moduleName=moduleName)):
         f = open('{dir}/modules/{category}/{moduleName}/ht_{moduleName}.py'.format(dir=dir_actual, category=category,
                                                                                    moduleName=moduleName), "w")
-        f.write(__default_template_modules_ht__.format(moduleName=moduleName))
+        f.write(__default_template_modules_ht__.replace('{moduleName}', moduleName))
     if not __os.path.exists(
             '{dir}/modules/{category}/{moduleName}/__init__.py'.format(dir=dir_actual, category=category,
                                                                        moduleName=moduleName)):
